@@ -1,14 +1,14 @@
 /*
- * Datei für übersetzbare Zeichenketten, erzeugt durch Glade.
- * Fügen Sie diese Datei zur POTFILES.in Ihres Projektes hinzu.
- * Compilieren Sie sie NICHT als Teil Ihrer Anwendung.
+ * Archivo de cadenas traducibles generado por Glade.
+ * Añada este archivo a su POTFILES.in de su proyecto.
+ * NO lo compile como parte de su aplicación.
  */
 
-gchar *s = N_("Use this tool to decide the services to be run and the runlevels in which they are run.");
+gchar *s = N_("Use this tool to specify which services to run and the runlevel for the services.");
 gchar *s = N_("<span weight=\"bold\">Description</span>");
 gchar *s = N_("Click on an item in the list to show it's description.");
 gchar *s = N_("Service _Properties");
-gchar *s = N_("Script name:");
+gchar *s = N_("Service:");
 gchar *s = N_("Description:");
 gchar *s = N_("<span weight=\"bold\">General Information</span>");
 gchar *s = N_("Parameters:");
