@@ -4,9 +4,8 @@
  * NO lo compile como parte de su aplicación.
  */
 
-gchar *s = N_("Select a time zone by clicking on \n"
-              "one of the dots on the map.");
-gchar *s = N_("Selection:");
+gchar *s = N_("To select a time zone, click on one of the dots on the map");
+gchar *s = N_("Time Zone:");
 gchar *s = N_("*");
 gchar *s = N_("Select the servers you wish to use for time synchronization.");
 gchar *s = N_("*");
@@ -20,6 +19,5 @@ gchar *s = N_(":");
 gchar *s = N_("(unconfigured)");
 gchar *s = N_("_Select Time Zone...");
 gchar *s = N_("_Date:");
-gchar *s = N_("<span weight=\"bold\">Time Server</span>");
+gchar *s = N_("S_ynchronize clock with Internet servers");
 gchar *s = N_("Se_lect Servers...");
-gchar *s = N_("S_ynchronize clock with internet servers");
