@@ -28,19 +28,66 @@
 #include <ctype.h>
 #include <gnome.h>
 
-#include "xst.h"
-#include "xst-report-hook.h"
+#include "gst.h"
+#include "gst-report-hook.h"
+#include "boot-image-editor.h"
+#include "boot-druid.h"
 #include "callbacks.h"
 #include "transfer.h"
 #include "table.h"
 
-extern XstTool *tool;
+extern GstTool *tool;
 extern GtkWidget *boot_table;
 extern GtkTreeIter default_entry_iter;
 
 extern GdkPixbuf *selected_icon;
 extern GdkPixbuf *not_selected_icon;
 
+
+void
+on_boot_add_clicked (GtkButton *button, gpointer data)
+{
+	BootDruid *druid;
+
+	if (gst_tool_get_access (tool)) {
+		druid = boot_druid_new ();
+
+		if (druid)
+			gtk_widget_show_all (GTK_WIDGET (druid));
+		else {
+			gchar *error = g_strdup ("Can't add more images, maximum count reached.");
+
+			boot_settings_gui_error (GTK_WINDOW (tool->main_dialog), error);
+		}
+	}
+}
+
+void
+on_boot_settings_clicked (GtkButton *button, gpointer data)
+{
+	GtkTreeSelection *selection;
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+	BootImage *image;
+	BootImageEditor *editor;
+	xmlNodePtr node;
+
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (boot_table));
+
+	if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
+		gtk_tree_model_get (model, &iter, BOOT_LIST_COL_POINTER, &node, -1);
+	}
+
+
+	if (gst_tool_get_access (tool)) {
+		image = boot_image_get_by_node (node);
+		editor = boot_image_editor_new (image);
+
+		gtk_widget_show (GTK_WIDGET (editor));
+	}
+}
+
+
 gboolean
 on_boot_table_clicked (GtkWidget *w, gpointer data)
 {
@@ -71,11 +118,11 @@ on_boot_table_clicked (GtkWidget *w, gpointer data)
 
 		/* we set the current iter as the default */
 		gtk_tree_model_get (model, &iter, BOOT_LIST_COL_POINTER, &node, -1);
-		label = xst_xml_get_child_content (node, "label");
-		xst_xml_set_child_content (xst_xml_doc_get_root (tool->config), "default", label);
+		label = gst_xml_get_child_content (node, "label");
+		gst_xml_set_child_content (gst_xml_doc_get_root (tool->config), "default", label);
 		default_entry_iter = iter;
 
-		xst_dialog_modify (tool->main_dialog);
+		gst_dialog_modify (tool->main_dialog);
 	}
 	
 	g_list_free (column_list);
@@ -90,35 +137,77 @@ on_boot_table_cursor_changed (GtkTreeSelection *selection, gpointer data)
 	callbacks_actions_set_sensitive (TRUE);
 }
 
+gboolean
+on_boot_table_button_press (GtkTreeView *treeview, GdkEventButton *event, gpointer gdata)
+{
+	GtkTreePath *path;
+	GtkItemFactory *factory;
+
+	factory = (GtkItemFactory *) gdata;
+
+	if (event->button == 3)
+	{
+		gtk_widget_grab_focus (GTK_WIDGET (treeview));
+		if (gtk_tree_view_get_path_at_pos (treeview, event->x, event->y, &path, NULL, NULL, NULL))
+		{
+			gtk_tree_selection_unselect_all (gtk_tree_view_get_selection (treeview));
+			gtk_tree_selection_select_path (gtk_tree_view_get_selection (treeview), path);
+
+			gtk_item_factory_popup (factory, event->x_root, event->y_root,
+						event->button, event->time);
+		}
+		return TRUE;
+	}
+	return FALSE;
+}
+
+void
+on_popup_add_activate (gpointer callback_data, guint action, GtkWidget *widget)
+{
+	on_boot_add_clicked (callback_data, NULL);
+}
+
+void
+on_popup_settings_activate (gpointer callback_data, guint action, GtkWidget *widget)
+{
+	on_boot_settings_clicked (callback_data, NULL);
+}
+
+void
+on_popup_delete_activate (gpointer callback_data, guint action, GtkWidget *widget)
+{
+	on_boot_delete_clicked (callback_data, NULL);
+}
+
 /* Helpers */
 
 void
 callbacks_actions_set_sensitive (gboolean state)
 {
-	XstDialogComplexity complexity;
+	GstDialogComplexity complexity;
 
 	complexity = tool->main_dialog->complexity;
 
-	if (xst_tool_get_access (tool) && complexity == XST_DIALOG_ADVANCED) {
-		gtk_widget_set_sensitive (xst_dialog_get_widget (tool->main_dialog, "boot_add"), TRUE);
-		gtk_widget_set_sensitive (xst_dialog_get_widget (tool->main_dialog, "boot_delete"),
+	if (gst_tool_get_access (tool) && complexity == GST_DIALOG_ADVANCED) {
+		gtk_widget_set_sensitive (gst_dialog_get_widget (tool->main_dialog, "boot_add"), TRUE);
+		gtk_widget_set_sensitive (gst_dialog_get_widget (tool->main_dialog, "boot_delete"),
 					  state);
 	}
 	
-	gtk_widget_set_sensitive (xst_dialog_get_widget (tool->main_dialog, "boot_settings"), state);
+	gtk_widget_set_sensitive (gst_dialog_get_widget (tool->main_dialog, "boot_settings"), state);
 }
 
 static void
-callbacks_buttons_set_visibility (XstDialog *main_dialog)
+callbacks_buttons_set_visibility (GstDialog *main_dialog)
 {
-	switch (xst_dialog_get_complexity (main_dialog)) {
-	case XST_DIALOG_ADVANCED:
-		gtk_widget_show (xst_dialog_get_widget (main_dialog, "boot_add"));
-		gtk_widget_show (xst_dialog_get_widget (main_dialog, "boot_delete"));
+	switch (gst_dialog_get_complexity (main_dialog)) {
+	case GST_DIALOG_ADVANCED:
+		gtk_widget_show (gst_dialog_get_widget (main_dialog, "boot_add"));
+		gtk_widget_show (gst_dialog_get_widget (main_dialog, "boot_delete"));
 		break;
-	case XST_DIALOG_BASIC:
-		gtk_widget_hide (xst_dialog_get_widget (main_dialog, "boot_add"));
-		gtk_widget_hide (xst_dialog_get_widget (main_dialog, "boot_delete"));
+	case GST_DIALOG_BASIC:
+		gtk_widget_hide (gst_dialog_get_widget (main_dialog, "boot_add"));
+		gtk_widget_hide (gst_dialog_get_widget (main_dialog, "boot_delete"));
 		break;
 	default:
 		g_warning ("Unknown complexity.");
@@ -139,9 +228,9 @@ on_boot_delete_clicked (GtkButton *button, gpointer data)
 	gint         count, reply;
 	GtkWidget   *d;
 	
-	g_return_if_fail (xst_tool_get_access (tool));
+	g_return_if_fail (gst_tool_get_access (tool));
 
-	count = boot_image_count (xst_xml_doc_get_root (tool->config));
+	count = boot_image_count (gst_xml_doc_get_root (tool->config));
 	if (count <= 1) {
 		d = gtk_message_dialog_new (GTK_WINDOW (tool->main_dialog),
 					    GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -161,7 +250,7 @@ on_boot_delete_clicked (GtkButton *button, gpointer data)
 		gtk_tree_model_get (model, &iter, BOOT_LIST_COL_POINTER, &node, -1);
 	}
 	
-	label = xst_xml_get_child_content (node, "label");
+	label = gst_xml_get_child_content (node, "label");
 	buf = g_strdup_printf (_("Are you sure you want to delete '%s'?"), label);
 	g_free (label);
 
@@ -178,16 +267,21 @@ on_boot_delete_clicked (GtkButton *button, gpointer data)
 	if (reply != GTK_RESPONSE_YES)
 		return;
 
-	xst_xml_element_destroy (node);
+	gst_xml_element_destroy (node);
 	boot_table_update ();
-	xst_dialog_modify (tool->main_dialog);
+	gst_dialog_modify (tool->main_dialog);
 	callbacks_actions_set_sensitive (FALSE);
 }
 
 void
-on_main_dialog_update_complexity (XstDialog *main_dialog, gpointer data)
+on_main_dialog_update_complexity (GstDialog *main_dialog, gpointer data)
 {
-	XstDialogComplexity complexity = xst_dialog_get_complexity (tool->main_dialog);
+	GstDialogComplexity complexity = gst_dialog_get_complexity (tool->main_dialog);
+	GtkTreeView *boot_table = GTK_TREE_VIEW (gst_dialog_get_widget (tool->main_dialog, "boot_table"));
+
+	gtk_tree_selection_unselect_all (gtk_tree_view_get_selection (boot_table));
+
+	callbacks_actions_set_sensitive (FALSE);
 	
 	boot_table_update_state (complexity);
 	
@@ -197,7 +291,7 @@ on_main_dialog_update_complexity (XstDialog *main_dialog, gpointer data)
 /* Hooks */
 
 gboolean
-callbacks_conf_read_failed_hook (XstTool *tool, XstReportLine *rline, gpointer data)
+callbacks_conf_read_failed_hook (GstTool *tool, GstReportLine *rline, gpointer data)
 {
 	GtkWidget *dialog;
 	gchar *txt;
