@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 #include <gtk/gtk.h>
 
-void on_ntp_addserver (GtkButton *button, XstDialog *dialog);
+void on_ntp_addserver (GtkButton *button, GstDialog *dialog);
 
 
